@@ -9,7 +9,7 @@ ARTEFACT="${NAME}-${VERSION}.tar.gz"
 FOLDER="${NAME}-${VERSION}"
 
 dzil clean &&
-dzil build || exit $?
+    dzil build || exit $?
 dzil cover --outputdir ../cover_db
 
 sleep 1
@@ -18,7 +18,7 @@ cp "${FOLDER}/cpanfile" ./
 cp "${FOLDER}/Makefile.PL" ./
 
 if [ $DEVELOPER_RELEASE -eq 1 ]; then
-    echo -- dzil release --trial
+    dzil release --trial
 else
-    echo -- dzil release
+    dzil release
 fi
